@@ -187,7 +187,9 @@ class ProxyPool:
         while True:
             with self.__update_lock:
                 if self.__pool.empty():
-                    return None
+                    print("Proxy pool is empty. Wait for 3 seconds and will retry...")
+                    time.sleep(3)
+                    continue
 
                 proxy_info = self.__pool.get(True)
 
